// Copyright (c) Microsoft Corporation. All rights reserved.
// Licensed under the MIT License.
import { __asyncValues, __awaiter } from "tslib";
// This sample shows you how to get a setting only if it has changed
// from what you already have. This allows your app to avoid downloading
// the contents of a setting if the value is unchanged.
// NOTE: replace with import { AppConfigurationClient } from "@azure/app-configuration"
// in a standalone project
import { AppConfigurationClient } from "../src";
export function run() {
    return __awaiter(this, void 0, void 0, function* () {
        console.log("Running get setting only if changed sample");
        // You will need to set this environment variable
        const connectionString = process.env["AZ_CONFIG_CONNECTION"];
        const client = new AppConfigurationClient(connectionString);
        const key = "getSettingOnlyIfChangedExample";
        yield cleanupSampleValues([key], client);
        const addedSetting = yield client.addConfigurationSetting({ key, value: "Initial value" });
        // now our application only wants to download the setting if it's changed
        console.log("Checking to see if the value has changed using the etag and ifNoneMatch");
        const unchangedResponse = yield client.getConfigurationSetting(addedSetting, {
            // onlyIfChanged allows us to say "get me the value only if it doesn't match the one I already have"
            // this allows us to avoid transferring the setting if nothing has changed.
            onlyIfChanged: true
        });
        // we return the response so you can still inspect the returned headers. The body, however, is blank
        console.log(`Received a response code of ${unchangedResponse.statusCode}`); // will be HTTP status 304
        // To prevent any accidental usages of this model all properties (except for 'key') are set to undefined.
        if (unchangedResponse.value !== undefined) {
            throw new Error("All properties should be undefined");
        }
        yield cleanupSampleValues([key], client);
    });
}
function cleanupSampleValues(keys, client) {
    var e_1, _a;
    return __awaiter(this, void 0, void 0, function* () {
        const existingSettings = yield client.listConfigurationSettings({
            keyFilter: keys.join(',')
        });
        try {
            for (var existingSettings_1 = __asyncValues(existingSettings), existingSettings_1_1; existingSettings_1_1 = yield existingSettings_1.next(), !existingSettings_1_1.done;) {
                const setting = existingSettings_1_1.value;
                yield client.setReadOnly(setting, false);
                yield client.deleteConfigurationSetting({ key: setting.key, label: setting.label });
            }
        }
        catch (e_1_1) { e_1 = { error: e_1_1 }; }
        finally {
            try {
                if (existingSettings_1_1 && !existingSettings_1_1.done && (_a = existingSettings_1.return)) yield _a.call(existingSettings_1);
            }
            finally { if (e_1) throw e_1.error; }
        }
    });
}
// If you want to run this sample from a console
// uncomment these lines so run() will get called
// run().catch(err => {
//     console.log(`ERROR: ${err}`);
// });
//# sourceMappingURL=getSettingOnlyIfChanged.js.map