// Copyright (c) Microsoft Corporation. All rights reserved.
// Licensed under the MIT License.
import { __asyncValues, __awaiter } from "tslib";
// This sample demonstrates the basics - creating settings, updating settings
// deleting settings and getting them.
// NOTE: replace with import { AppConfigurationClient } from "@azure/app-configuration"
// in a standalone project
import { AppConfigurationClient } from "../src";
export function run() {
    return __awaiter(this, void 0, void 0, function* () {
        console.log(`Running helloworld sample`);
        // You will need to set this environment variable
        const connectionString = process.env["AZ_CONFIG_CONNECTION"];
        const client = new AppConfigurationClient(connectionString);
        const greetingKey = "Samples:Greeting";
        yield cleanupSampleValues([greetingKey], client);
        // creating a new setting
        console.log(`Adding in new setting ${greetingKey}`);
        yield client.addConfigurationSetting({ key: greetingKey, value: "Hello!" });
        const newSetting = yield client.getConfigurationSetting({ key: greetingKey });
        console.log(`${greetingKey} has been set to ${newSetting.value}`);
        // changing the value of a setting
        yield client.setConfigurationSetting({ key: greetingKey, value: "Goodbye!" });
        const updatedSetting = yield client.getConfigurationSetting({ key: greetingKey });
        console.log(`${greetingKey} has been set to ${updatedSetting.value}`);
        // removing the setting
        yield client.deleteConfigurationSetting({ key: greetingKey });
        console.log(`${greetingKey} has been deleted`);
        yield cleanupSampleValues([greetingKey], client);
    });
}
function cleanupSampleValues(keys, client) {
    var e_1, _a;
    return __awaiter(this, void 0, void 0, function* () {
        const settingsIterator = yield client.listConfigurationSettings({
            keyFilter: keys.join(',')
        });
        try {
            for (var settingsIterator_1 = __asyncValues(settingsIterator), settingsIterator_1_1; settingsIterator_1_1 = yield settingsIterator_1.next(), !settingsIterator_1_1.done;) {
                const setting = settingsIterator_1_1.value;
                yield client.deleteConfigurationSetting({ key: setting.key, label: setting.label });
            }
        }
        catch (e_1_1) { e_1 = { error: e_1_1 }; }
        finally {
            try {
                if (settingsIterator_1_1 && !settingsIterator_1_1.done && (_a = settingsIterator_1.return)) yield _a.call(settingsIterator_1);
            }
            finally { if (e_1) throw e_1.error; }
        }
    });
}
// If you want to run this sample from a console
// uncomment these lines so run() will get called
// run().catch(err => {
//     console.log(`ERROR: ${err}`);
// });
//# sourceMappingURL=helloworld.js.map