// Copyright (c) Microsoft Corporation. All rights reserved.
// Licensed under the MIT License.
import { __asyncValues, __awaiter } from "tslib";
// This sample builds on concepts in helloworld.ts and shows you how 
// to use labels. Labels allow you to add an extra dimension for your 
// setting and gives you a simple way to create conventions for environments. 
// 
// For additional information about how labels work see:
// https://docs.microsoft.com/en-us/azure/azure-app-configuration/concept-key-value#label-keys
// NOTE: replace with import { AppConfigurationClient } from "@azure/app-configuration"
// in a standalone project
import { AppConfigurationClient } from "../src";
export function run() {
    return __awaiter(this, void 0, void 0, function* () {
        console.log("Running helloworldWithLabels sample");
        // You will need to set this environment variable
        const connectionString = process.env["AZ_CONFIG_CONNECTION"];
        const client = new AppConfigurationClient(connectionString);
        const urlKey = "Samples:Endpoint:Url";
        yield cleanupSampleValues([urlKey], client);
        // labels allow you to use the same key with different values for separate environments
        // or clients
        console.log("Adding in endpoint with two labels - beta and production");
        yield client.addConfigurationSetting({ key: urlKey, label: "beta", value: "https://beta.example.com" });
        yield client.addConfigurationSetting({ key: urlKey, label: "production", value: "https://example.com" });
        const betaEndpoint = yield client.getConfigurationSetting({ key: urlKey, label: "beta" });
        console.log(`Endpoint with beta label: ${betaEndpoint.value}`);
        const productionEndpoint = yield client.getConfigurationSetting({ key: urlKey, label: "production" });
        console.log(`Endpoint with production label: ${productionEndpoint.value}`);
        yield cleanupSampleValues([urlKey], client);
    });
}
function cleanupSampleValues(keys, client) {
    var e_1, _a;
    return __awaiter(this, void 0, void 0, function* () {
        const existingSettings = yield client.listConfigurationSettings({
            keyFilter: keys.join(',')
        });
        try {
            for (var existingSettings_1 = __asyncValues(existingSettings), existingSettings_1_1; existingSettings_1_1 = yield existingSettings_1.next(), !existingSettings_1_1.done;) {
                const setting = existingSettings_1_1.value;
                yield client.deleteConfigurationSetting({ key: setting.key, label: setting.label });
            }
        }
        catch (e_1_1) { e_1 = { error: e_1_1 }; }
        finally {
            try {
                if (existingSettings_1_1 && !existingSettings_1_1.done && (_a = existingSettings_1.return)) yield _a.call(existingSettings_1);
            }
            finally { if (e_1) throw e_1.error; }
        }
    });
}
// If you want to run this sample from a console
// uncomment these lines so run() will get called
// run().catch(err => {
//     console.log(`ERROR: ${err}`);
// });
//# sourceMappingURL=helloworldWithLabels.js.map