// Copyright (c) Microsoft Corporation. All rights reserved.
// Licensed under the MIT License.
import { __asyncValues, __awaiter } from "tslib";
// This sample demonstrates how to list revisions for a configuration 
// setting.
// NOTE: replace with import { AppConfigurationClient } from "@azure/app-configuration"
// in a standalone project
import { AppConfigurationClient } from "../src";
export function run() {
    var e_1, _a;
    return __awaiter(this, void 0, void 0, function* () {
        console.log(`Running listRevisions sample`);
        // You will need to set this environment variable
        const connectionString = process.env["AZ_CONFIG_CONNECTION"];
        const client = new AppConfigurationClient(connectionString);
        // let's create the setting
        const originalSetting = yield client.addConfigurationSetting({
            key: `keyWithRevisions-${Date.now()}`,
            value: "original value"
        });
        console.log(`First revision created with value ${originalSetting.value}`);
        const newSetting = Object.assign(Object.assign({}, originalSetting), { value: "A new value!" });
        // delay for a second to make the timestamps more interesting
        yield new Promise((resolve) => setTimeout(resolve, 1000));
        // now we'll update it - this leaves us with two revisions (the previous 'original' and
        // our update)
        yield client.setConfigurationSetting(newSetting);
        const revisionsIterator = client.listRevisions({
            keyFilter: newSetting.key
        });
        try {
            // show all the revisions, including the date they were set.
            for (var revisionsIterator_1 = __asyncValues(revisionsIterator), revisionsIterator_1_1; revisionsIterator_1_1 = yield revisionsIterator_1.next(), !revisionsIterator_1_1.done;) {
                const revision = revisionsIterator_1_1.value;
                // revisions are just a configuration setting at a particular point in time
                console.log(`At ${revision.lastModified}, the value was ${revision.value}`);
            }
        }
        catch (e_1_1) { e_1 = { error: e_1_1 }; }
        finally {
            try {
                if (revisionsIterator_1_1 && !revisionsIterator_1_1.done && (_a = revisionsIterator_1.return)) yield _a.call(revisionsIterator_1);
            }
            finally { if (e_1) throw e_1.error; }
        }
        cleanupSampleValues([originalSetting.key], client);
    });
}
function cleanupSampleValues(keys, client) {
    var e_2, _a;
    return __awaiter(this, void 0, void 0, function* () {
        const settingsIterator = yield client.listConfigurationSettings({
            keyFilter: keys.join(',')
        });
        try {
            for (var settingsIterator_1 = __asyncValues(settingsIterator), settingsIterator_1_1; settingsIterator_1_1 = yield settingsIterator_1.next(), !settingsIterator_1_1.done;) {
                const setting = settingsIterator_1_1.value;
                yield client.deleteConfigurationSetting({ key: setting.key, label: setting.label });
            }
        }
        catch (e_2_1) { e_2 = { error: e_2_1 }; }
        finally {
            try {
                if (settingsIterator_1_1 && !settingsIterator_1_1.done && (_a = settingsIterator_1.return)) yield _a.call(settingsIterator_1);
            }
            finally { if (e_2) throw e_2.error; }
        }
    });
}
// If you want to run this sample from a console
// uncomment these lines so run() will get called
// run().catch(err => {
//     console.log(`ERROR: ${err}`);
// });
//# sourceMappingURL=listRevisions.js.map